package application;

import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.util.List;
import java.util.Scanner;

import engine.EngineFactory;
import engine.IEngine;


public final class ClientApplication {
	public static void main(String[] args){
		EngineFactory engineFactory = new EngineFactory();
		IEngine engine = engineFactory.createMainEngine();

		
		Scanner reader = new Scanner(System.in);
		System.out.println("Please provide the name of the input file, or just give 0 for the default:");
		String filename = reader.next().trim();
		if(filename.equalsIgnoreCase("0"))
			filename = "src/test/resources/input/demoTimeLine.txt";
		int parseFileFlag = engine.setTimeLine(filename);	
		if(parseFileFlag < 0) {
			System.out.println("The file does not exist; switching to the default file");
			filename = "src/test/resources/input/demoTimeLine.txt";
			engine.setTimeLine(filename);
		}
		System.out.println(engine.consoleVerticalReport());
		
		while(true){
			System.out.println("0. exit, 1. ProducePhases, 2. Visualize time series, 3. Report phases, 5. Exit");
			int answer = reader.nextInt();
			if(answer == 1){
				int numPhases = 0;
				numPhases = engine.producePhases();
				System.out.println(numPhases + " phases were produced...");
			}
			else if(answer == 2){
				System.out.println("Choose visualizer: 1. Html Visualizer, 2. Console visualizer:");
				int visAnswer = reader.nextInt();
				if(visAnswer == 1){
					engine.setVisualizer("HtmlVisualizer");
					System.out.println("Give me a fileName to report:");
					String outputFilename = reader.next().trim();
					try {
						PrintStream prinstream = new PrintStream(outputFilename);
						engine.visualize(prinstream);		
					} catch (FileNotFoundException e) {
						System.out.println("Problem opening file " + outputFilename + ". Exiting now");
						System.exit(0);
					} 
				}
				else if(visAnswer == 2){
					engine.setVisualizer("ConsoleVisualizer");
					engine.visualize(System.out);	
				}
			}
			else if(answer == 3){
				List<String> phaseReports = engine.reportPhases();
				for(String pr: phaseReports)
					System.out.println(pr);
			}
			else{
				System.out.println("Exiting now...");
				break;
			}
		}
		
		reader.close();
	}
}
